@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2016-10-22'; # DATE
-our $VERSION = '0.54'; # VERSION
+our $DATE = '2016-10-26'; # DATE
+our $VERSION = '0.55'; # VERSION
 
 use 5.010001;
 use strict;
@@ -149,6 +149,8 @@ my %complete_array_elem_args = (
     array       => {
         schema => ['array*'=>{of=>'str*'}],
         req => 1,
+        pos => 1,
+        greedy => 1,
     },
     exclude     => {
         schema => ['array*'],
@@ -607,7 +609,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.54 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-22.
+This document describes version 0.55 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-26.
 
 =head1 DESCRIPTION
 
